@@ -1236,6 +1236,7 @@ impl Config {
 
     pub fn is_compatible(&self) -> Result<bool> {
         let result = match self.parsed_version()? {
+            (0, 8, 1) => true,
             (0, 8, 0) => true,
             (_, _, _) => false,
         };
@@ -1245,7 +1246,8 @@ impl Config {
 
     pub fn upgrade_notification(&self) -> Result<Option<&str>> {
         let result = match self.parsed_version()? {
-            (0, 8, 0) => None,
+            (0, 8, 1) => None,
+            (0, 8, 0) => Some("App version updated. Fixed breaking UI after rename"),
             (_, _, _) => None,
         };
 
